@@ -14,7 +14,7 @@ use crate::{Row, RowBuf, Stage};
 /// would result in less-than ideal data layouts and doesn't fit with the 'only pay for what you
 /// use' design goal of this library.
 #[repr(u8)]
-#[derive(Eq, PartialEq, Hash, Debug, Copy, Clone)]
+#[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub enum Parity {
     /// A given [`Row`] requires an **even** number of [`swap`](Row::swap)s to return to
     /// [`rounds`](RowBuf::rounds).  This is also often called _in course_ or _positive_.  The
@@ -102,7 +102,7 @@ mod tests {
 
     #[test]
     fn row_parity() {
-        assert_eq!(RowBuf::rounds(Stage::ZERO).parity(), Even);
+        assert_eq!(RowBuf::rounds(Stage::TWO).parity(), Even);
         assert_eq!(RowBuf::rounds(Stage::MAJOR).parity(), Even);
         assert_eq!(RowBuf::parse("13245").unwrap().parity(), Odd);
         assert_eq!(RowBuf::parse("231546").unwrap().parity(), Odd);
